@@ -13,6 +13,7 @@ from ..SystemTools import get_core_num
 from .. import (
     user_lang,
     qs_default_console,
+    qs_default_status,
     qs_error_string,
     qs_info_string,
     qs_warning_string,
@@ -50,18 +51,17 @@ def GetBlockSize(sz):
 
 
 def ask_overwrite(path: str):
-    from ..__config__ import prompt
+    from .. import _ask
 
-    return prompt(
+    return _ask(
         {
             "type": "confirm",
-            "name": "overwrite",
             "message": f'"{path}" 已存在, 是否覆盖?'
             if user_lang == "zh"
             else f'"{path}" already exists, overwrite?',
             "default": False,
         }
-    )["overwrite"]
+    )
 
 
 class Downloader:
@@ -105,7 +105,7 @@ class Downloader:
         self.disableStatus = disableStatus
         self.write_to_memory = write_to_memory
         if not self.disableStatus:
-            with qs_default_console.status(
+            with qs_default_status(
                 "Getting file info.." if user_lang != "zh" else "获取文件信息中.."
             ):
                 self.url, self.name, r = get_fileinfo(url, proxy, referer)
@@ -123,6 +123,13 @@ class Downloader:
             if failed2exit:
                 self.enabled = False
                 return
+        if not self.url:
+            qs_default_console.print(
+                qs_error_string, "Connection Error!" if user_lang != "zh" else "连接失败!"
+            )
+            self.enabled = False
+            return
+
         if self.name and "." not in self.name:
             self.name = os.path.basename(url)
         if name:
@@ -137,9 +144,6 @@ class Downloader:
         self.headers = headers
         if referer:
             self.headers["Referer"] = referer
-        if not self.url:
-            qs_default_console.print(qs_error_string, self.name)
-            raise Exception("Connection Error!" if user_lang != "zh" else "连接失败!")
         try:
             if not info_flag:
                 raise KeyError
